# Nonlinear Pendulum
# m*L*d^2(theat)/dt^2=-m*g*sin(theta)
# equivalently d^2theta/dt^2=-g/L*sin(theat)
# set dtheta/dt=w

import numpy as np
import matplotlib.pyplot as plt

def f(r, t):
  global g, L
  f_theta=r[1]
  f_w=-g/L*np.sin(r[0])
  return np.array([f_theta, f_w])

t=np.linspace(0, 5, 1000)
h=t[1]-t[0]
theta=np.zeros(len(t))
omega=np.zeros(len(t))
# INITIAL STATE
theta[0]=np.pi-0.5*np.pi
omega[0]=0
g= 9.81; L=0.1

for i in range(len(t)-1):   # 4-th order RKM
  r=[theta[i], omega[i]]
  k_1=h*f(r, t[i])
  k_2=h*f(r+k_1/2, t[i]+h/2)
  k_3=h*f(r+k_2/2, t[i]+h/2)
  k_4=h*f(r+k_3, t[i]+h)
  theta[i+1], omega[i+1]=r+(k_1+2*k_2+2*k_3+k_4)/6

plt.plot(t, theta)
plt.plot(t, omega)
plt.xlabel(r"$t$")
plt.ylabel(r"$\theta(t)$, $\omega(t)$")
plt.show()
